@@ -1,8 +1,11 @@
 # ==================== core.py ====================
 from collections import deque
 
-from llama_index.core.agent.workflow import FunctionAgent
-from llama_index.core.tools import FunctionTool
+from llama_index.core.agent.workflow import FunctionAgent, ReActAgent
+
+# --- hotfix: corrige erro "unhashable type: 'FunctionAgent'" ---
+FunctionAgent.__hash__ = lambda self: id(self)
+# ---------------------------------------------------------------
 
 from hermes.utils import (
     get_api_key_from_provider,
@@ -66,27 +69,41 @@ class Agent:
         # Convert tools and agents to FunctionTools
         self.tools = convert_tools_to_function_tools(tools, self)
 
-        # Initialize the agent with the first key (will be replaced in execute)
+        # Initialize llm and tokenizer
+        self.llm, self.tokenize_func = get_model_from_provider(
+            self.provider,
+            self.model,
+            get_random_api_key(self.api_keys),
+            self.temperature,
+            self.debug,
+            len(self.api_keys) > 1,
+        )
+
+        # Initialize the agent
         self.agent = None
         self._initialize_agent()
 
     def _initialize_agent(self):
         """Initialize or reinitialize the agent with current API key."""
-        self.agent = FunctionAgent(
-            name=self.name,
-            description=self.description,
-            system_prompt=get_enhanced_prompt(
-                self.name, self.description, self.prompt, self.tools
-            ),
-            tools=self.tools,
-            llm=get_model_from_provider(
+        # Reinitialize llm with a new random API key if multiple keys are available
+        if len(self.api_keys) > 1:
+            self.llm, self.tokenize_func = get_model_from_provider(
                 self.provider,
                 self.model,
                 get_random_api_key(self.api_keys),
                 self.temperature,
                 self.debug,
                 len(self.api_keys) > 1,
+            )
+
+        self.agent = ReActAgent(
+            name=self.name,
+            description=self.description,
+            system_prompt=get_enhanced_prompt(
+                self.name, self.description, self.prompt, []
             ),
+            tools=self.tools,
+            llm=self.llm,
         )
 
     async def execute(self, input_data=None, chat_history=None):
@@ -105,9 +122,3 @@ class Agent:
             return response
         except Exception as e:
             return f"Error executing agent: {str(e)}"
-
-    async def execute_web_interface(self):
-        """Serve the agent's web interface."""
-        from hermes.utils import execute_web_interface
-
-        await execute_web_interface(directory="hermes/web_interface")
\ No newline at end of file
