@@ -2,12 +2,12 @@
 import os
 import random
 import asyncio
+import tiktoken
 from datetime import datetime
 import yake
 from langdetect import detect
 from dotenv import load_dotenv
-from pathlib import Path
-from importlib import resources
+from llama_index.llms.litellm import LiteLLM
 
 from llama_index.core.tools import FunctionTool
 
@@ -128,7 +128,7 @@ def get_model_from_provider(
     provider, model, api_key, temperature, debug, has_multiple_keys
 ):
     """
-    Dynamically import and return the model based on the provider.
+    Dynamically import and return the model based on the provider using LiteLLM.
 
     Args:
         provider: The provider name (e.g., 'openai', 'anthropic')
@@ -139,7 +139,7 @@ def get_model_from_provider(
         has_multiple_keys: Whether multiple API keys are available
 
     Returns:
-        The initialized model instance
+        The initialized LiteLLM model instance
     """
     try:
         if has_multiple_keys and debug:
@@ -149,44 +149,16 @@ def get_model_from_provider(
             )
             print(f"🔑 Using API key: {masked_key}")
 
-        if provider == "openai":
-            from llama_index.llms.openai import OpenAI
+        llm = LiteLLM(
+            model=model, api_key=api_key, temperature=temperature, max_tokens=500
+        )
+        tokenizer_fn = tiktoken.encoding_for_model(model_name=model).encode
 
-            return OpenAI(
-                model=model,
-                api_key=api_key,
-                temperature=temperature,
-            )
-        elif provider == "azure":
-            from llama_index.llms.azure_openai import AzureOpenAI
-
-            return AzureOpenAI(
-                model=model,
-                api_key=api_key,
-                temperature=temperature,
-            )
-        elif provider == "anthropic":
-            from llama_index.llms.anthropic import Anthropic
-
-            return Anthropic(
-                model=model,
-                api_key=api_key,
-                temperature=temperature,
-            )
-        elif provider in ["gemini", "google"]:
-            from llama_index.llms.google_genai import GoogleGenAI
-
-            return GoogleGenAI(
-                model=model,
-                api_key=api_key,
-                temperature=temperature,
-            )
-        else:
-            raise ValueError(f"Unsupported provider: {provider}")
-    except ImportError as e:
-        raise ImportError(
-            f"Failed to import model for provider {provider}. "
-            f"Please ensure the required package is installed."
+        return llm, tokenizer_fn
+    except Exception as e:
+        raise RuntimeError(
+            f"Failed to initialize LiteLLM model for provider {provider}. "
+            f"Error: {str(e)}"
         ) from e
 
 
@@ -243,29 +215,22 @@ def create_agent_wrapper(agent_instance, debug):
 
 
 def convert_tools_to_function_tools(tools, agent_instance):
-    """
-    Convert functions and Agent instances to FunctionTool objects automatically.
-
-    Args:
-        tools: List containing functions, FunctionTools, or Agent instances
-        agent_instance: The Agent instance that owns these tools (for accessing debug flag)
-
-    Returns:
-        List of FunctionTool objects
-    """
-    # Import here to avoid circular dependency
     from hermes.core import Agent
+    from llama_index.core.agent.workflow import FunctionAgent
 
     converted_tools = []
 
     for tool in tools:
-        # If it's an Agent instance, create wrapper function
+        # Bloquear FunctionAgent diretamente (não é suportado)
+        if isinstance(tool, FunctionAgent):
+            if agent_instance.debug:
+                print(f"⚠️ Ignorando FunctionAgent inválido: {tool.name}")
+            continue
+
         if isinstance(tool, Agent):
             if agent_instance.debug:
-                print(f"✨ Creating automatic tool for agent: {tool.name}")
+                print(f"✨ Criando tool automática para agent: {tool.name}")
             wrapper_func = create_agent_wrapper(tool, agent_instance.debug)
-
-            # Create FunctionTool from wrapper function
             converted_tool = FunctionTool.from_defaults(
                 fn=wrapper_func,
                 name=wrapper_func.__name__,
@@ -273,7 +238,6 @@ def convert_tools_to_function_tools(tools, agent_instance):
             )
             converted_tools.append(converted_tool)
 
-        # If it's a regular function (not FunctionTool)
         elif callable(tool) and not isinstance(tool, FunctionTool):
             tool_name = tool.__name__
             tool_description = tool.__doc__ or f"Tool for {tool_name}"
@@ -282,7 +246,6 @@ def convert_tools_to_function_tools(tools, agent_instance):
             )
             converted_tools.append(converted_tool)
 
-        # If it's already a FunctionTool, use directly
         else:
             converted_tools.append(tool)
 
@@ -365,27 +328,3 @@ def enhance_input_data(input_data, debug):
         print(f"\n🛠️ Enhanced Input Data:\n{format_text(enhanced_input)}\n")
 
     return format_text(enhanced_input)
-
-
-async def execute_web_interface(port=8000, directory="hermes/web_interface"):
-    from hermes.web import serve_static_fastapi
-    import hermes
-
-    try:
-        # Absolute path inside the installed package
-        package_dir = Path(resources.files(hermes) / "web_interface")
-
-        # Check if it exists inside the installed package
-        if package_dir.exists():
-            await serve_static_fastapi(port=port, directory=str(package_dir))
-            return
-
-    except Exception:
-        pass  # Fallback if package is not packaged yet (dev mode)
-
-    # Dev mode: try relative path (useful when running directly from repo)
-    relative_dir = Path(__file__).resolve().parent / "web_interface"
-    if relative_dir.exists():
-        await serve_static_fastapi(port=port, directory=str(relative_dir))
-    else:
-        raise RuntimeError(f"Could not find web_interface folder at: {relative_dir}")
